@@ -1,6 +1,6 @@
-# Copyright 2023 DARWIN EU®
+# Copyright 2024 DARWIN EU®
 #
-# This file is part of IncidencePrevalence
+# This file is part of CodelistGenerator
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,8 +14,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
-
 #' Generate candidate codelist for the OMOP CDM
 #'
 #' @description
@@ -126,11 +124,10 @@ getCandidateCodes <- function(cdm,
     searchSpecs[, c("id")]
   )
 
-  searchResults <- lapply(searchSpecs, function(x) {
-    result <- runSearch(keywords,
+  searchResults <- runSearch(keywords,
       cdm = cdm,
       exclude = exclude,
-      domains = x$domain,
+      domains = domains,
       standardConcept = standardConcept,
       searchInSynonyms = searchInSynonyms,
       searchNonStandard = searchNonStandard,
@@ -138,26 +135,11 @@ getCandidateCodes <- function(cdm,
       includeAncestor = includeAncestor
     )
 
-    return(result)
-  })
-
-  # drop any empty tibbles and put results from each domain together
-  searchResults <- searchResults[lapply(searchResults, nrow) > 0]
-  searchResults <- dplyr::bind_rows(searchResults,
-    .id = NULL
-  ) %>%
-    dplyr::distinct()
-
   if (nrow(searchResults) == 0) {
     cli::cli_inform("No codes found for the given search strategy")
     return(searchResults)
   }
 
-  # add concept info
-  searchResults <- addDetails(cdm = cdm,
-             conceptList = searchResults) %>%
-    dplyr::filter(tolower(.data$domain_id) %in% tolower(.env$domains))
-
   cli::cli_alert_success(
     "{nrow(searchResults)} candidate concept{?s} identified"
   )
