@@ -1,6 +1,6 @@
-# Copyright 2023 DARWIN EU®
+# Copyright 2024 DARWIN EU®
 #
-# This file is part of IncidencePrevalence
+# This file is part of CodelistGenerator
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -27,12 +27,16 @@
 #' cdm
 #' CDMConnector::cdmDisconnect(cdm)
 #' }
-mockVocabRef <- function(backend = "database") {
+mockVocabRef <- function(backend = "data_frame") {
   errorMessage <- checkmate::makeAssertCollection()
   checkmate::assertTRUE(backend %in% c("database", "data_frame"))
   checkmate::assertTRUE(length(backend) == 1)
   checkmate::reportAssertions(collection = errorMessage)
 
+  if(backend == "database"){
+    rlang::check_installed("duckdb")
+  }
+
   # compulsory tables
   person <- dplyr::tibble(
     person_id = 1, gender_concept_id = 0, year_of_birth = 1990,
@@ -349,6 +353,6 @@ mockVocabRef <- function(backend = "database") {
                           cdm = cdm_df,
                           schema = "main",
                           overwrite = TRUE)
-
+  attr(cdm, "write_schema") <- "main"
   cdm
 }
